Module: ActiveRecord::XmlSerialization

Defined in:
lib/active_record/xml_serialization.rb

Instance Method Summary collapse

Instance Method Details

#to_xml(options = {}) ⇒ Object

Builds an XML document to represent the model. Some configuration is availble through options, however more complicated cases should use override ActiveRecord's to_xml.

By default the generated XML document will include the processing instruction and all object's attributes. For example:

The First Topic David 1 false 0 2000-01-01T08:28:00+12:00 2003-07-16T09:28:00+1200 Have a nice day [email protected] 2004-04-15

This behavior can be controlled with :only, :except, :skip_instruct, :skip_types and :dasherize. The :only and :except options are the same as for the #attributes method. The default is to dasherize all column names, to disable this, set :dasherize to false. To not have the column type included in the XML output, set :skip_types to false.

For instance:

topic.to_xml(:skip_instruct => true, :except => [ :id, :bonus_time, :written_on, :replies_count ])
The First Topic David false Have a nice day [email protected] 2004-04-15

To include first level associations use :include

firm.to_xml :include => [ :account, :clients ]
1 1 37signals 1 Summit 1 Microsoft 1 50

To include any methods on the object(s) being called use :methods

firm.to_xml :methods => [ :calculated_earnings, :real_earnings ]
# ... normal attributes as shown above ... 100000000000000000 5

To call any Proc's on the object(s) use :procs. The Proc's are passed a modified version of the options hash that was given to #to_xml.

proc = Proc.new { |options| options[:builder].tag!('abc', 'def') }
firm.to_xml :procs => [ proc ]
# ... normal attributes as shown above ... def

You may override the to_xml method in your ActiveRecord::Base subclasses if you need to. The general form of doing this is

class IHaveMyOwnXML < ActiveRecord::Base
def to_xml(options = {})
  options[:indent] ||= 2
  xml = options[:builder] ||= Builder::XmlMarkup.new(:indent => options[:indent])
  xml.instruct! unless options[:skip_instruct]
  xml.level_one do
    xml.tag!(:second_level, 'content')
  end
end
end


106
107
108
# File 'lib/active_record/xml_serialization.rb', line 106

def to_xml(options = {})
  XmlSerializer.new(self, options).to_s
end