Module: ActiveRecord::XmlSerialization
- Defined in:
- lib/active_record/xml_serialization.rb
Instance Method Summary collapse
-
#to_xml(options = {}) ⇒ Object
Builds an XML document to represent the model.
Instance Method Details
#to_xml(options = {}) ⇒ Object
Builds an XML document to represent the model. Some configuration is
availble through options, however more complicated cases should use
override ActiveRecord's to_xml.
By default the generated XML document will include the processing instruction and all object's attributes. For example:
This behavior can be controlled with :only, :except, :skip_instruct, :skip_types and :dasherize. The :only and :except options are the same as for the #attributes method. The default is to dasherize all column names, to disable this, set :dasherize to false. To not have the column type included in the XML output, set :skip_types to false.
For instance:
topic.to_xml(:skip_instruct => true, :except => [ :id, :bonus_time, :written_on, :replies_count ])
To include first level associations use :include
firm.to_xml :include => [ :account, :clients ]
To include any methods on the object(s) being called use :methods
firm.to_xml :methods => [ :calculated_earnings, :real_earnings ]
To call any Proc's on the object(s) use :procs. The Proc's are passed a modified version of the options hash that was given to #to_xml.
proc = Proc.new { || [:builder].tag!('abc', 'def') }
firm.to_xml :procs => [ proc ]
You may override the to_xml method in your ActiveRecord::Base subclasses if you need to. The general form of doing this is
class IHaveMyOwnXML < ActiveRecord::Base
def to_xml( = {})
[:indent] ||= 2
xml = [:builder] ||= Builder::XmlMarkup.new(:indent => [:indent])
xml.instruct! unless [:skip_instruct]
xml.level_one do
xml.tag!(:second_level, 'content')
end
end
end
106 107 108 |
# File 'lib/active_record/xml_serialization.rb', line 106 def to_xml( = {}) XmlSerializer.new(self, ).to_s end |